===================
Welcome to wildboar
===================

Wildboar is a package for supervised and unsupervised machine learning for time
series data.

.. toctree::
   :hidden:
   :maxdepth: 3

   install
   tutorial
   guide
   examples
   API Reference <wildboar/index>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
